# -*- coding: UTF-8 -*-

# Import from standard library
import os
import proj
import pandas as pd
# Import from our lib
from proj.lib import clean_data
import pytest


def test_clean_data():
    datapath = os.path.dirname(os.path.abspath(proj.__file__)) + '/data'
    df = pd.read_csv('{}/data.csv.gz'.format(datapath))
    first_cols = ['id', 'civility', 'birthdate', 'city', 'postal_code', 'vote_1']
    assert list(df.columns)[:6] == first_cols
    assert df.shape == (999, 142)
    out = clean_data(df)
    assert out.shape == (985, 119)



# -*- coding: UTF-8 -*-

from os.path import abspath
from os.path import dirname
import pandas as pd


def get_data():
    """ Create data
    """
    return "tons of data"


def clean_data(data):
    """ clean data
    """
    return data.upper()


def make_result(df, filename):
    """ write output result in filename
    """
    df.drop(["datetime", "timestamp", "score_value"], axis=1, inplace=True)
    df["player"] = df.player.str.upper()
    df.to_csv(filename)
    print("  {} Made")


if __name__ == "__main__":
    # For introspections purpose to quickly get this functions on ipython
    # with data
    import wagon_tools

    datapath = dirname(abspath(wagon_tools.__file__)) + "/data"
    data = "{}/data.csv".format(datapath)
    df = pd.read_csv(data)
    data = get_data()
    clean_data = clean_data(data)
    print("df, data and clean_data made")



# -*- coding: UTF-8 -*-

# Import from standard library
import os
import wagon_tools
import unittest
import pandas as pd

# Import from our lib
from wagon_tools.lib import get_data, clean_data


class TestUtils(unittest.TestCase):

    def test_get_data(self):
        res = 'tons of data'
        out = get_data()
        self.assertEqual(res, out)

    # @unittest.skip('')
    def test_clean_data(self):
        datapath = os.path.dirname(os.path.abspath(wagon_tools.__file__)) + '/data'
        df = pd.read_csv('{}/data.csv'.format(datapath))
        out = clean_data(df.columns[3])
        self.assertEqual('GAME', out)


if __name__ == '__main__':
    unittest.main()



from setuptools import find_packages
from setuptools import setup

with open('requirements.txt') as f:
    content = f.readlines()
requirements = [x.strip() for x in content if 'git+' not in x]

setup(name='proj',
      setup_requires=['setuptools_scm'],
      install_requires=requirements,
      use_scm_version={'write_to': 'proj/version.txt'},
      description="proj_description",
      packages=find_packages(),
      test_suite = 'tests',
      # include_package_data: to install data from MANIFEST.in
      include_package_data=True,
      scripts=['scripts/proj-run'],
      zip_safe=False)



# -*- coding: UTF-8 -*-
# Copyright (C) 2018 Jean Bizot <jean@styckr.io>
""" Main lib for proj Project
"""

from os.path import split
import pandas as pd
import datetime

pd.set_option('display.width', 200)


def clean_data(data):
    """ clean data
    """
    # Remove columns starts with vote
    cols = [x for x in data.columns if x.find('vote') >= 0]
    data.drop(cols, axis=1, inplace=True)
    # Remove special characteres from columns
    data.loc[:, 'civility'] = data['civility'].replace('\.', '', regex=True)
    # Calculate Age from day of birth
    actual_year = datetime.datetime.now().year
    data.loc[:, 'Year_Month'] = pd.to_datetime(data.birthdate)
    data.loc[:, 'Age'] = actual_year - data['Year_Month'].dt.year
    # Uppercase variable to avoid duplicates
    data.loc[:, 'city'] = data['city'].str.upper()
    # Take 2 first digits, 2700 -> 02700 so first two are region
    data.loc[:, 'postal_code'] = data.postal_code.str.zfill(5).str[0:2]
    # Remove columns with more than 50% of nans
    cnans = data.shape[0] / 2
    data = data.dropna(thresh=cnans, axis=1)
    # Remove rows with more than 50% of nans
    rnans = data.shape[1] / 2
    data = data.dropna(thresh=rnans, axis=0)
    # Discretize based on quantiles
    data.loc[:, 'duration'] = pd.qcut(data['surveyduration'], 10)
    # Discretize based on values
    data.loc[:, 'Age'] = pd.cut(data['Age'], 10)
    # Rename columns
    data.rename(columns={'q1': 'Frequency'}, inplace=True)
    # Transform type of columns
    data.loc[:, 'Frequency'] = data['Frequency'].astype(int)
    # Rename values in rows
    drows = {1: 'Manytimes', 2: 'Onetimebyday', 3: '5/6timesforweek',
             4: '4timesforweek', 5: '1/3timesforweek', 6: '1timeformonth',
             7: '1/trimestre', 8: 'Less', 9: 'Never'}
    data.loc[:, 'Frequency'] = data['Frequency'].map(drows)
    return data


if __name__ == '__main__':
    # For introspections purpose to quickly get this functions on ipython
    import proj
    folder_source, _ = split(proj.__file__)
    df = pd.read_csv('{}/data/data.csv.gz'.format(folder_source))
    clean_data = clean_data(df)
    print(' dataframe cleaned')



import pathlib
from setuptools import setup, find_packages
# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()


setup(name='wagon_tools',
      version="1.1.1",
      # Below to deal with cleaner versionning
      #setup_requires=['setuptools_scm'],
      #install_requires=['setuptools_scm'],
      #use_scm_version={'write_to': 'wagon_tools/version.txt'},
      description="Package builder with CI included",
      long_description=README,
      long_description_content_type="text/markdown",
      url="https://github.com/lologibus2/wagon_tools",
      author='Jean Bizot', author_email="jea@gmail.com",
      packages=find_packages(),
      test_suite='tests',
      # include_package_data: to install data from MANIFEST.in
      include_package_data=True,
      scripts=['scripts/wagon-make-package'],
      zip_safe=False)
